/*
 *  Copyright (C) 2009 Ludovic Jacomme (ludovic.jacomme@gmail.com)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <stdio.h>
#include <zlib.h>
#include <unistd.h>
#include <sys/stat.h>
#include "SDL.h"



#include <stdlib.h>
#include <stdio.h>
#include <string.h>

#include "gp2x_cpu.h"
#include "psp_global.h"
#include "psp_fmgr.h"
#include "psp_menu.h"
#include "psp_sdl.h"

  GGO_t GGO;

int
psp_global_reset()
{
  GGO.current_x = 0;
  GGO.current_y = 0;
  GGO.last_move_x = 0;
  GGO.last_move_y = 0;
  GGO.passes  = 0;
  GGO.game_over = 0;

  return 0;
}

int
psp_global_init()
{
  int index;

  memset(&GGO, sizeof(GGO_t), 0);
  GGO.board_max_width = 19;
  GGO.board_min_width = 5;
  GGO.board_max_size  = GGO.board_max_width * GGO.board_max_width;
  GGO.board_width = 5;
  GGO.go_show_coord = 1;

  /* all colors */
  GGO.grid_color  = 0x0;
  GGO.coord_color = 0x0;
  GGO.last_color_black = GP2X_DEF_WHITE_COLOR;
  GGO.last_color_white = GP2X_DEF_BLACK_COLOR;
  GGO.game_color  = GP2X_DEF_WARNING_COLOR;
  GGO.xor_color   = psp_sdl_rgb(0xff, 0xff, 0xff);
  GGO.menu_warning_color = GP2X_DEF_WARNING_COLOR;
  GGO.menu_select_color  = GP2X_DEF_SEL_COLOR;
  GGO.menu_text_color    = GP2X_DEF_TEXT_COLOR;
  GGO.menu_black_color   = GP2X_DEF_BLACK_COLOR;
  GGO.menu_green_color   = GP2X_DEF_GREEN_COLOR;
  GGO.menu_white_color   = GP2X_DEF_WHITE_COLOR;
  GGO.menu_red_color     = GP2X_DEF_RED_COLOR;
  GGO.menu_note_color    = GP2X_DEF_NOTE_COLOR;
  GGO.menu_help_color    = GP2X_DEF_HELP_COLOR;

  GGO.go_handicap     = 0;
  GGO.go_level        = 5; /* max is 10 */
  GGO.go_komi         = 0;
  GGO.go_game_mode    = GGO_HUMAN_VS_COMPUTER;
  GGO.go_player_color = GGO_BLACK;
  GGO.psp_cpu_clock   = GP2X_DEF_CLOCK;

  strcpy(GGO.game_filename, "new_game.sgf");

  GGO.psp_screenshot_mode = 0;

  GGO.max_skin = psp_fmgr_get_dir_list( "./skins/", GGO_MAX_SKIN, GGO.skin_dirs );
  for (index = 0; index < GGO.max_skin; index++) {
    char *scan = strchr( GGO.skin_dirs[ index ], '/');
    if (scan) *scan = '\0';
  }
  strcpy(GGO.skin_name, "default" );

  psp_parse_configuration();
  psp_parse_skin_configuration();
  psp_sdl_load_skin();
  psp_global_reset();

  gp2xPowerSetClockFrequency(GGO.psp_cpu_clock);
  return 0;
}

int
psp_save_configuration(void)
{
  char  FileName[MAX_PATH];
  FILE* FileDesc;
  int   error = 0;

  strcpy(FileName, "./go.cfg");

  FileDesc = fopen(FileName, "w");
  if (FileDesc != (FILE *)0 ) {

    fprintf(FileDesc, "psp_cpu_clock=%d\n"  , GGO.psp_cpu_clock);
    fprintf(FileDesc, "go_handicap=%d\n"    , GGO.go_handicap);
    fprintf(FileDesc, "go_game_mode=%d\n"   , GGO.go_game_mode);
    fprintf(FileDesc, "go_komi=%d\n"        , GGO.go_komi);
    fprintf(FileDesc, "go_level=%d\n"       , GGO.go_level);
    fprintf(FileDesc, "go_player_color=%d\n", GGO.go_player_color);
    fprintf(FileDesc, "go_board_width=%d\n" , GGO.board_width);
    fprintf(FileDesc, "skin_name=%s\n"      , GGO.skin_name );
    fprintf(FileDesc, "go_show_coord=%d\n"  , GGO.go_show_coord);

    fclose(FileDesc);

  } else {
    error = 1;
  }

  return error;
}

int
psp_parse_configuration(void)
{
  char  FileName[MAX_PATH+1];
  char  Buffer[512];
  char *Scan;
  FILE* FileDesc;
  int   Value;

  strcpy(FileName, "./go.cfg");

  FileDesc = fopen(FileName, "r");
  if (FileDesc == (FILE *)0 ) return 0;

  while (fgets(Buffer,512, FileDesc) != (char *)0) {

    Scan = strchr(Buffer,'\n');
    if (Scan) *Scan = '\0';
    /* For this #@$% of windows ! */
    Scan = strchr(Buffer,'\r');
    if (Scan) *Scan = '\0';
    if (Buffer[0] == '#') continue;

    Scan = strchr(Buffer,'=');
    if (! Scan) continue;

    *Scan = '\0'; Scan++;
    if ((Scan[0] == '0') && (Scan[1] == 'x')) {
      sscanf(Scan, "%x", &Value);
    } else {
      Value = atoi(Scan);
    }

    if (!strcasecmp(Buffer,"psp_cpu_clock")) GGO.psp_cpu_clock = Value;
    else
    if (!strcasecmp(Buffer,"go_handicap")) GGO.go_handicap = Value;
    else
    if (!strcasecmp(Buffer,"go_level")) GGO.go_level = Value;
    else
    if (!strcasecmp(Buffer,"go_game_mode")) GGO.go_game_mode = Value;
    else
    if (!strcasecmp(Buffer,"go_komi")) GGO.go_komi = Value;
    else
    if (!strcasecmp(Buffer,"go_player_color")) GGO.go_player_color = Value;
    else
    if (!strcasecmp(Buffer,"go_board_width")) GGO.board_width = Value;
    else
    if (!strcasecmp(Buffer,"skin_name")) strcpy( GGO.skin_name, Scan );
    else
    if (!strcasecmp(Buffer,"go_show_coord")) GGO.go_show_coord = Value;
  }

  fclose(FileDesc);

  return 0;
}

int
psp_parse_skin_configuration(void)
{
  char  Buffer[512];
  char  FileName[MAX_PATH+1];
  char *Scan;
  FILE* FileDesc;
  int   Value;

  sprintf(FileName, "./skins/%s/skin.cfg", GGO.skin_name );
  FileDesc = fopen(FileName, "r");
  if (FileDesc == (FILE *)0 ) {
    strcpy(FileName, "./skins/default/skin.cfg");
    FileDesc = fopen(FileName, "r");
  }

  if (FileDesc == (FILE *)0 ) return 0;
  while (fgets(Buffer,512, FileDesc) != (char *)0) {

    Scan = strchr(Buffer,'\n');
    if (Scan) *Scan = '\0';
    /* For this #@$% of windows ! */
    Scan = strchr(Buffer,'\r');
    if (Scan) *Scan = '\0';
    if (Buffer[0] == '#') continue;

    Scan = strchr(Buffer,'=');
    if (! Scan) continue;

    *Scan = '\0';
    Scan++;
    if ((Scan[0] == '0') && (Scan[1] == 'x')) {
      sscanf(Scan, "%x", &Value);
      // convert rgb to 656
      Value = psp_sdl_rgb( (Value >> 16) & 0xFF, (Value >> 8) & 0xFF, Value & 0xFF );
    } else {
      Value = atoi(Scan);
    }

    if (!strcasecmp(Buffer,"grid_color")) GGO.grid_color = Value;
    else
    if (!strcasecmp(Buffer,"coord_color")) GGO.coord_color = Value;
    else
    if (!strcasecmp(Buffer,"game_color")) GGO.game_color = Value;
    else
    if (!strcasecmp(Buffer,"last_color_white")) GGO.last_color_white = Value;
    else
    if (!strcasecmp(Buffer,"last_color_black")) GGO.last_color_black = Value;
    else
    if (!strcasecmp(Buffer, "menu_warning_color")) GGO.menu_warning_color = Value;
    else
    if (!strcasecmp(Buffer, "menu_select_color"))  GGO.menu_select_color  = Value;
    else
    if (!strcasecmp(Buffer, "menu_text_color"))    GGO.menu_text_color    = Value;
    else
    if (!strcasecmp(Buffer, "menu_black_color"))   GGO.menu_black_color   = Value;
    else
    if (!strcasecmp(Buffer, "menu_green_color"))   GGO.menu_green_color   = Value;
    else
    if (!strcasecmp(Buffer, "menu_white_color"))   GGO.menu_white_color   = Value;
    else
    if (!strcasecmp(Buffer, "menu_red_color"))     GGO.menu_red_color     = Value;
    else
    if (!strcasecmp(Buffer, "menu_note_color"))    GGO.menu_note_color    = Value;
    else
    if (!strcasecmp(Buffer, "menu_help_color"))    GGO.menu_help_color    = Value;
  }

  fclose(FileDesc);

  return 0;
}

int
psp_change_skin( const char* skin_name )
{
  if (! strcasecmp( GGO.skin_name, skin_name)) {
    return 0;
  }
  strcpy( GGO.skin_name, skin_name );
  psp_parse_skin_configuration();
  // psp_sdl_load_skin();

  return 1;
}
