/*
 *  Copyright (C) 2007 Ludovic Jacomme (ludovic.jacomme@gmail.com)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

# ifndef _GP2X_GLOBAL_H_
# define _GP2X_GLOBAL_H_

#include "gnugo.h"

# define MAX_PATH   128

# define GGO_EMPTY  0
# define GGO_BLACK  1
# define GGO_WHITE  2

# define GGO_HUMAN_VS_COMPUTER     0
# define GGO_HUMAN_VS_HUMAN        1
# define GGO_COMPUTER_VS_COMPUTER  2

# define GGO_MAX_SKIN       50

  typedef struct GGO_t {

    char  game_filename[MAX_PATH];

    int   board_max_width;
    int   board_min_width;
    int   board_max_size;

    int   board_width;

    int   current_x;
    int   current_y;
    int   last_move_x;
    int   last_move_y;
    int   passes;
    int   game_over;

    int      sgf_initialized;
    Gameinfo gameinfo;
    SGFTree  sgftree;

    int      go_handicap;
    int      go_player_color; /* black or white ? */
    int      go_level;
    int      go_game_mode; /* vs computer ? */
    int      go_komi;
    int      go_show_coord;
    
    int      psp_cpu_clock;
    int      psp_screenshot_mode;
    int      psp_screenshot_id;

    char     skin_name[MAX_PATH];
    char    *skin_dirs[GGO_MAX_SKIN];
    int      max_skin;

    /* all colors */
    int      xor_color;
    int      grid_color;
    int      coord_color;
    int      game_color;
    int      last_color_white;
    int      last_color_black;
    int      menu_warning_color;
    int      menu_select_color;
    int      menu_text_color;
    int      menu_black_color;
    int      menu_white_color;
    int      menu_red_color;
    int      menu_green_color;
    int      menu_note_color;
    int      menu_help_color;

  } GGO_t;

  extern GGO_t GGO;

  extern int psp_global_reset();
  extern int psp_parse_configuration(void);
  extern int psp_save_configuration(void);
  extern int psp_change_skin( const char* skin_name );

# endif
